==> owncloud-10.0.7.tgz: owncloud/apps/federatedfilesharing/l10n/nl.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Federated sharing",
    "Invalid Federated Cloud ID" : "Ongeldige Federated Cloud ID",
    "Sharing %s failed, because this item is already shared with %s" : "Delen van %s is mislukt, omdat het object al wordt gedeeld met %s",
    "Not allowed to create a federated share with the same user" : "Het is niet toegestaan om een gefedereerde share met dezelfde gebruikersserver te maken",
    "File is already shared with %s" : "Bestand is al gedeeld met %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Delen van %s mislukt, kon %s niet vinden, misschien is de server niet bereikbaar.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "U ontving \"/%3$s\" als een externe share van %1$s (namens %2$s)",
    "You received \"/%3$s\" as a remote share from %1$s" : "U ontving \"/%3$s\" as een externe share van %1$s",
    "Accept" : "Accepteren",
    "Decline" : "Afwijzen",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Deel met mij via mijn #ownCloud federated Cloud ID, zie %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Deel met mij via mijn #ownCloud federated Cloud ID",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "Open documentation" : "Open documentatie",
    "Allow users on this server to send shares to other servers" : "Toestaan dat gebruikers op deze server shares sturen naar andere servers",
    "Allow users on this server to receive shares from other servers" : "Toestaan dat gebruikers op deze server shares ontvangen van andere servers",
    "Federated Cloud" : "Gefedereerde Cloud",
    "Your Federated Cloud ID:" : "Uw Federated Cloud ID:",
    "Share it:" : "Deel het:",
    "Add to your website" : "Toevoegen aan uw website",
    "Share with me via ownCloud" : "Deel met mij via ownCloud",
    "HTML Code:" : "HTML Code:"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/apps/federatedfilesharing/l10n/nl.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Federated sharing",
    "Invalid Federated Cloud ID" : "Ongeldige Federated Cloud ID",
    "Sharing %s failed, because this item is already shared with %s" : "Delen van %s is mislukt, omdat het object al wordt gedeeld met %s",
    "Not allowed to create a federated share with the same user" : "Het is niet toegestaan om een gefedereerde share met dezelfde gebruikersserver te maken",
    "File is already shared with %s" : "Bestand is al gedeeld met %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Delen van %s mislukt, kon %s niet vinden, misschien is de server niet bereikbaar.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "U ontving \"/%3$s\" als een externe share van %1$s (namens %2$s)",
    "You received \"/%3$s\" as a remote share from %1$s" : "U ontving \"/%3$s\" as een externe share van %1$s",
    "Accept" : "Accepteren",
    "Decline" : "Afwijzen",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Deel met mij via mijn #ownCloud federated Cloud ID, zie %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Deel met mij via mijn #ownCloud federated Cloud ID",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "Open documentation" : "Open documentatie",
    "Allow users on this server to send shares to other servers" : "Toestaan dat gebruikers op deze server shares sturen naar andere servers",
    "Allow users on this server to receive shares from other servers" : "Toestaan dat gebruikers op deze server shares ontvangen van andere servers",
    "Federated Cloud" : "Gefedereerde Cloud",
    "Your Federated Cloud ID:" : "Uw Federated Cloud ID:",
    "Share it:" : "Deel het:",
    "Add to your website" : "Toevoegen aan uw website",
    "Share with me via ownCloud" : "Deel met mij via ownCloud",
    "HTML Code:" : "HTML Code:",
    "Add to your ownCloud" : "Toevoegen aan uw ownCloud"
},
"nplurals=2; plural=(n != 1);");
